@@ -251,14 +251,14 @@ addContributors theLemma uu
        thetheLemma <- liftIO . (base (counter sst)) $ theLemma
        thetheHostname <- liftIO . (base (counter sst)) . hostname $ st
        thetheUU <- liftIO . (base (counter sst)) $ uu
-       au <- (liftIO (((liftA3 (counter sst) fun) thetheLemma thetheHostname thetheUU)))
+       au <- (liftIO (((liftA3 (counter sst) (fun sst)) thetheLemma thetheHostname thetheUU)))
                :: ImperativeMonad (MVar (Map String Contributor, Maybe String))
        auau <- liftIO ((liftA (counter sst) (return . fst)) au)
        lic <- liftIO ((liftA (counter sst) (return . snd)) au)
        put sst{audict = auau : (audict sst)}
        return lic
-  where fun lem ho uuu
-          = do xx <- simpleContributors lem ho uuu
+  where fun ssst lem ho uuu 
+          = do xx <- simpleContributors lem ho uuu ssst
                return (Data.List.foldl runGo2 Map.empty xx, myvalue xx)
         runGo2 mymap (author, theHref, theEdits, _)
           = Map.alter (infun author theHref (fromIntegral theEdits)) author
